@@ -58,7 +58,7 @@ class ViewGeneralMethods:
             else:
                 action_text = 'updated'
                 model_object = model.query.get_or_404(object_id)
-                self.generic_update(model_object.to_json(), data)
+                self.generic_update(model_object, data)
             self.db.session.commit()
         except ValueError:
             self.db.session.rollback()
